# Allowed Ghosts 👻

1. app-virgem-maria.cloud.sdu.dk
1. app-basilio-magno-e-gregorio-nazianzo.cloud.sdu.dk
1. app-santa-genoveva.cloud.sdu.dk
1. app-zedislava-de-lemberk.cloud.sdu.dk
1. app-santa-apolinaria.cloud.sdu.dk
1. app-santa-estefania.cloud.sdu.dk
1. app-raimundo-de-penhaforte.cloud.sdu.dk
1. app-sao-lourenco-justiniano.cloud.sdu.dk
1. app-sao-juliao.cloud.sdu.dk
1. app-beato-goncalo-de-amarante.cloud.sdu.dk
1. app-bernardo-scammacca.cloud.sdu.dk
1. app-santo-arcadio.cloud.sdu.dk
1. app-hilario-de-poitiers.cloud.sdu.dk
1. app-pedro-donders.cloud.sdu.dk
1. app-santo-amaro-festas-solenes-em-algumas-localidades-portuguesas.cloud.sdu.dk
1. app-de-janeiro.cloud.sdu.dk
1. app-santo-antao.cloud.sdu.dk
1. app-santo-irmao-jaime-hilario.cloud.sdu.dk
1. app-andre-de-peschiera.cloud.sdu.dk
1. app-sao-sebastiao.cloud.sdu.dk
1. app-santa-ines.cloud.sdu.dk
1. app-sao-vicente.cloud.sdu.dk
1. app-henrique-de-suso.cloud.sdu.dk
1. app-sao-francisco-de-sales.cloud.sdu.dk
1. app-conversao-de-sao-paulo.cloud.sdu.dk
1. app-sao-timoteo-e-sao-tito.cloud.sdu.dk
1. app-angela-merici.cloud.sdu.dk
1. app-tomas-de-aquino.cloud.sdu.dk
1. app-josef-freinademetz.cloud.sdu.dk
1. app-carlos-i-da-inglaterra.cloud.sdu.dk
1. app-sao-joao-bosco.cloud.sdu.dk
1. app-santa-brigida.cloud.sdu.dk
1. app-apresentacao-do-senhor.cloud.sdu.dk
1. app-sao-lourenco-de-cantuaria-e-sao-bras-de-sebaste.cloud.sdu.dk
1. app-sao-joao-de-brito.cloud.sdu.dk
1. app-santa-agueda.cloud.sdu.dk
1. app-santa-doroteia.cloud.sdu.dk
1. app-cinco-chagas-do-senhor.cloud.sdu.dk
1. app-sao-jeronimo-emiliano.cloud.sdu.dk
1. app-santa-apolonia.cloud.sdu.dk
1. app-santa-escolastica.cloud.sdu.dk
1. app-nossa-senhora-de-lourdes.cloud.sdu.dk
1. app-santa-eulalia-de-barcelona.cloud.sdu.dk
1. app-sao-marciniano.cloud.sdu.dk
1. app-sao-valentim.cloud.sdu.dk
1. app-sao-claudio-colombiere.cloud.sdu.dk
1. app-santo-onesimo.cloud.sdu.dk
1. app-santo-aleixo.cloud.sdu.dk
1. app-sao-teotonio.cloud.sdu.dk
1. app-santa-belina.cloud.sdu.dk
1. app-santos-francisco-e-jacinta-de-fatima.cloud.sdu.dk
1. app-sao-pedro-damiao.cloud.sdu.dk
1. app-catedra-de-sao-pedro.cloud.sdu.dk
1. app-santa-margarida-de-cortona.cloud.sdu.dk
1. app-sao-policarpo.cloud.sdu.dk
1. app-sao-sergio.cloud.sdu.dk
1. app-sao-luigi-versiglia-e-sao-callisto-caravario.cloud.sdu.dk
1. app-santo-alexandre-do-egito.cloud.sdu.dk
1. app-sao-gabriel-de-nossa-senhora-das-dores.cloud.sdu.dk
1. app-sao-romano.cloud.sdu.dk
1. app-santo-osvaldo.cloud.sdu.dk
1. app-sao-david.cloud.sdu.dk
1. app-santa-ines-da-boemia.cloud.sdu.dk
1. app-santos-marino-e-asterio.cloud.sdu.dk
1. app-sao-casimiro.cloud.sdu.dk
1. app-sao-joao-jose-da-cruz.cloud.sdu.dk
1. app-santa-rosa-de-viterbo.cloud.sdu.dk
1. app-santa-perpetua-e-santa-felicidade.cloud.sdu.dk
1. app-nossa-senhora-das-lagrimas.cloud.sdu.dk
1. app-santa-francisca-romana.cloud.sdu.dk
1. app-os-santos-martires-de-sebaste.cloud.sdu.dk
1. app-sao-militao-e-seus-companheiros.cloud.sdu.dk
1. app-papa-gregorio-i.cloud.sdu.dk
1. app-sao-rodrigo.cloud.sdu.dk
1. app-santo-antonio-de-categero.cloud.sdu.dk
1. app-santa-matilde.cloud.sdu.dk
1. app-sao-henrique.cloud.sdu.dk
1. app-sao-patricio.cloud.sdu.dk
1. app-sao-cirilo-de-jerusalem.cloud.sdu.dk
1. app-sao-jose.cloud.sdu.dk
1. app-santa-maria-josefina-do-coracao-de-jesus-sancho-de-guerra.cloud.sdu.dk
1. app-sao-bento.cloud.sdu.dk
1. app-sao-berilo.cloud.sdu.dk
1. app-sao-oscar-romero.cloud.sdu.dk
1. app-sao-toribio-de-mongrovejo.cloud.sdu.dk
1. app-nossa-senhora-da-encarnacao-e-sao-dimas.cloud.sdu.dk
1. app-santa-larissa.cloud.sdu.dk
1. app-sao-roberto.cloud.sdu.dk
1. app-santo-alexandre.cloud.sdu.dk
1. app-sao-bertoldo.cloud.sdu.dk
1. app-sao-quirino-de-neuss.cloud.sdu.dk
1. app-santa-balbina.cloud.sdu.dk
1. app-sao-hugo.cloud.sdu.dk
1. app-sao-francisco-de-paula.cloud.sdu.dk
1. app-sao-ricardo.cloud.sdu.dk
1. app-santo-isidoro.cloud.sdu.dk
1. app-vicente-ferrer.cloud.sdu.dk
1. app-sao-marcelino.cloud.sdu.dk
1. app-sao-joao-batista-de-la-salle.cloud.sdu.dk
1. app-sao-dionisio.cloud.sdu.dk
1. app-santa-maria-de-cleofas.cloud.sdu.dk
1. app-santa-madalena-de-canossa.cloud.sdu.dk
1. app-santo-estanislau.cloud.sdu.dk
1. app-santa-hertha.cloud.sdu.dk
1. app-sao-martinho-i.cloud.sdu.dk
1. app-santa-liduina.cloud.sdu.dk
1. app-cesar-de-bus.cloud.sdu.dk
1. app-santa-isabella-gilmore.cloud.sdu.dk
1. app-santo-aniceto.cloud.sdu.dk
1. app-santo-apolonio.cloud.sdu.dk
1. app-sao-leao-ix-e-santo-expedito.cloud.sdu.dk
1. app-santa-ines-de-montepulciano-virgem.cloud.sdu.dk
1. app-santo-anselmo.cloud.sdu.dk
1. app-sao-caio.cloud.sdu.dk
1. app-sao-jorge.cloud.sdu.dk
1. app-sao-fiel-de-sigmaringa.cloud.sdu.dk
1. app-sao-marcos-evangelista.cloud.sdu.dk
1. app-santa-montserrat.cloud.sdu.dk
1. app-santa-zita.cloud.sdu.dk
1. app-sao-pedro-chanel.cloud.sdu.dk
1. app-santa-catarina-de-siena.cloud.sdu.dk
1. app-sao-pio-v.cloud.sdu.dk
1. app-sao-jose-operario-e-sao-jeremias.cloud.sdu.dk
1. app-santo-atanasio.cloud.sdu.dk
1. app-sao-filipe-e-sao-tiago.cloud.sdu.dk
1. app-sao-peregrino-e-sao-gotardo.cloud.sdu.dk
1. app-sao-angelo-da-sicilia.cloud.sdu.dk
1. app-sao-domingos-savio.cloud.sdu.dk
1. app-santa-flavia.cloud.sdu.dk
1. app-nossa-senhora-da-estrela-e-santa-emilie-de-villeneuve.cloud.sdu.dk
1. app-sao-pacomio.cloud.sdu.dk
1. app-sao-damiao-de-molokai.cloud.sdu.dk
1. app-santo-inacio-de-lacomi.cloud.sdu.dk
1. app-santos-nereu-e-aquileu.cloud.sdu.dk
1. app-nossa-senhora-de-fatima-e-beata-imelda-lambertini.cloud.sdu.dk
1. app-sao-matias.cloud.sdu.dk
1. app-santa-dymphna.cloud.sdu.dk
1. app-sao-joao-nepomuceno.cloud.sdu.dk
1. app-santa-junia.cloud.sdu.dk
1. app-sao-joao-i.cloud.sdu.dk
1. app-santo-ivo.cloud.sdu.dk
1. app-sao-bernardino-de-siena.cloud.sdu.dk
1. app-sao-cristovao-de-magalhaes-e-companheiros-martires.cloud.sdu.dk
1. app-santa-rita-de-cassia.cloud.sdu.dk
1. app-sao-joao-batista-de-rossi.cloud.sdu.dk
1. app-nossa-senhora-auxiliadora-e-de-santa-sara-kali.cloud.sdu.dk
1. app-sao-beda-veneravel.cloud.sdu.dk
1. app-sao-filipe-de-neri.cloud.sdu.dk
1. app-santo-agostinho-de-cantuaria.cloud.sdu.dk
1. app-bem.cloud.sdu.dk
1. app-santo-alexandre-de-jerusalem.cloud.sdu.dk
1. app-santa-joana-d-arc.cloud.sdu.dk
1. app-virgem-maria-bem.cloud.sdu.dk
1. app-sao-justino.cloud.sdu.dk
1. app-sao-marcelino-e-sao-pedro.cloud.sdu.dk
1. app-sao-carlos-lwanga-e-companheiros.cloud.sdu.dk
1. app-sao-francisco-caracciolo.cloud.sdu.dk
1. app-sao-bonifacio.cloud.sdu.dk
1. app-sao-norberto.cloud.sdu.dk
1. app-santo-antonio-maria-gianelli.cloud.sdu.dk
1. app-santo-efrem.cloud.sdu.dk
1. app-sao-jose-de-anchieta.cloud.sdu.dk
1. app-santo-anjo-da-guarda-de-portugal-e-santa-olivia.cloud.sdu.dk
1. app-sao-barnabe.cloud.sdu.dk
1. app-santo-onofre.cloud.sdu.dk
1. app-santo-antonio-de-lisboa.cloud.sdu.dk
1. app-sao-bartolomeu.cloud.sdu.dk
1. app-santa-germana-de-pibrac.cloud.sdu.dk
1. app-sao-manuel.cloud.sdu.dk
1. app-sao-ranieri-de-pisa.cloud.sdu.dk
1. app-beata-hosana-de-mantua.cloud.sdu.dk
1. app-sao-romualdo.cloud.sdu.dk
1. app-beata-sancha-de-portugal-e-beata-mafalda-de-portugal.cloud.sdu.dk
1. app-sao-luis-de-gonzaga.cloud.sdu.dk
1. app-sao-paulino-de-nola.cloud.sdu.dk
1. app-vigilia-da-natividade-de-sao-joao-baptista.cloud.sdu.dk
1. app-nascimento-de-sao-joao-baptista.cloud.sdu.dk
1. app-sao-maximo-de-turim.cloud.sdu.dk
1. app-sao-josemaria-escriva-de-balaguer.cloud.sdu.dk
1. app-sao-cirilo-de-alexandria.cloud.sdu.dk
1. app-santo-irineu.cloud.sdu.dk
1. app-sao-pedro.cloud.sdu.dk
1. app-primeiros-santos-martires-da-igreja-de-roma.cloud.sdu.dk
1. app-santo-aarao.cloud.sdu.dk
1. app-sao-bernardino-realino.cloud.sdu.dk
1. app-sao-tome.cloud.sdu.dk
1. app-isabel-de-portugal.cloud.sdu.dk
1. app-antonio-maria-zaccaria.cloud.sdu.dk
1. app-maria-goretti.cloud.sdu.dk
1. app-papa-adriano-iii.cloud.sdu.dk
1. app-papa-eugenio-iii.cloud.sdu.dk
1. app-santa-paulina.cloud.sdu.dk
1. app-santo-olavo.cloud.sdu.dk
1. app-joao-gualberto.cloud.sdu.dk
1. app-henrique-da-baviera.cloud.sdu.dk
1. app-sao-camilo-de-lellis.cloud.sdu.dk
1. app-sao-boaventura.cloud.sdu.dk
1. app-nossa-senhora-do-carmo.cloud.sdu.dk
1. app-santa-marcelina.cloud.sdu.dk
1. app-sao-francisco-solano.cloud.sdu.dk
1. app-santo-arsenio.cloud.sdu.dk
1. app-sao-simaco.cloud.sdu.dk
1. app-santa-margarida-de-antioquia.cloud.sdu.dk
1. app-sao-lourenco-de-brindisi.cloud.sdu.dk
1. app-maria-madalena.cloud.sdu.dk
1. app-santa-cristina.cloud.sdu.dk
1. app-sao-cristovao-e-sao-tiago.cloud.sdu.dk
1. app-santa-ana-e-sao-joaquim.cloud.sdu.dk
1. app-santa-bartolomeia.cloud.sdu.dk
1. app-santo-inocencio-i.cloud.sdu.dk
1. app-santa-marta.cloud.sdu.dk
1. app-pedro-crisologo.cloud.sdu.dk
1. app-sao-fabio.cloud.sdu.dk
1. app-afonso-de-ligorio.cloud.sdu.dk
1. app-eusebio-de-vercelas.cloud.sdu.dk
1. app-sao-nicodemos.cloud.sdu.dk
1. app-joao-maria-vianney.cloud.sdu.dk
1. app-santa-maria-maior.cloud.sdu.dk
1. app-transfiguracao-do-senhor-e-papa-hormisda.cloud.sdu.dk
1. app-sisto-ii.cloud.sdu.dk
1. app-sao-domingos-de-gusmao.cloud.sdu.dk
1. app-teresa-benedita-da-cruz.cloud.sdu.dk
1. app-sao-lourenco.cloud.sdu.dk
1. app-santa-clara-de-assis.cloud.sdu.dk
1. app-beato-amadeu-da-silva.cloud.sdu.dk
1. app-santa-dulce-dos-pobres.cloud.sdu.dk
1. app-maximiliano-kolbe.cloud.sdu.dk
1. app-solenidade-da-assuncao-da-virgem-maria.cloud.sdu.dk
1. app-santo-estevao-da-hungria.cloud.sdu.dk
1. app-santa-beatriz-da-silva.cloud.sdu.dk
1. app-santa-helena.cloud.sdu.dk
1. app-sao-joao-eudes.cloud.sdu.dk
1. app-sao-bernardo.cloud.sdu.dk
1. app-sao-pio-x.cloud.sdu.dk
1. app-nossa-senhora-rainha.cloud.sdu.dk
1. app-santa-rosa-de-lima.cloud.sdu.dk
1. app-sao-luis-de-franca.cloud.sdu.dk
1. app-sao-zeferino.cloud.sdu.dk
1. app-santa-monica.cloud.sdu.dk
1. app-agostinho-de-hipona.cloud.sdu.dk
1. app-martirio-de-sao-joao-batista.cloud.sdu.dk
1. app-sao-felix-e-santo-adauto.cloud.sdu.dk
1. app-sao-raimundo-nonato.cloud.sdu.dk
1. app-santa-vibiana-de-roma.cloud.sdu.dk
1. app-sao-gregorio-magno.cloud.sdu.dk
1. app-santa-rosalia.cloud.sdu.dk
1. app-santa-teresa-de-calcuta.cloud.sdu.dk
1. app-sao-zacarias.cloud.sdu.dk
1. app-santa-regina.cloud.sdu.dk
1. app-festa-da-natividade-de-nossa-senhora.cloud.sdu.dk
1. app-nossa-senhora-da-penha-de-franca.cloud.sdu.dk
1. app-sao-pedro-claver.cloud.sdu.dk
1. app-sao-nicolau-de-tolentino.cloud.sdu.dk
1. app-sao-joao-gabriel-perboyre.cloud.sdu.dk
1. app-sao-guido-de-anderlecht.cloud.sdu.dk
1. app-joao-crisostomo.cloud.sdu.dk
1. app-exaltacao-da-santa-cruz.cloud.sdu.dk
1. app-nossa-senhora-das-dores.cloud.sdu.dk
1. app-sao-cornelio.cloud.sdu.dk
1. app-roberto-belarmino.cloud.sdu.dk
1. app-sao-jose-copertino.cloud.sdu.dk
1. app-sao-januario.cloud.sdu.dk
1. app-santo-andre-kim-taegon-e-companheiros.cloud.sdu.dk
1. app-sao-mateus.cloud.sdu.dk
1. app-sao-mauricio.cloud.sdu.dk
1. app-sao-pio-de-pietrelcina.cloud.sdu.dk
1. app-nossa-senhora-das-merces.cloud.sdu.dk
1. app-santa-aurelia-e-sao-cleofas.cloud.sdu.dk
1. app-sao-cosme-e-damiao.cloud.sdu.dk
1. app-vicente-de-paulo.cloud.sdu.dk
1. app-sao-venceslau.cloud.sdu.dk
1. app-sao-miguel.cloud.sdu.dk
1. app-sao-jeronimo.cloud.sdu.dk
1. app-santa-teresinha-do-menino-jesus-e-da-santa-face.cloud.sdu.dk
1. app-santos-anjos-da-guarda.cloud.sdu.dk
1. app-beatos-andre-de-soveral.cloud.sdu.dk
1. app-sao-francisco-de-assis.cloud.sdu.dk
1. app-sao-benedito.cloud.sdu.dk
1. app-sao-bruno.cloud.sdu.dk
1. app-nossa-senhora-do-rosario.cloud.sdu.dk
1. app-santa-pelagia-penitente.cloud.sdu.dk
1. app-sao-luis-beltran.cloud.sdu.dk
1. app-sao-daniel-comboni.cloud.sdu.dk
1. app-sao-joao-xxiii.cloud.sdu.dk
1. app-nossa-senhora-aparecida.cloud.sdu.dk
1. app-beata-alexandrina-de-balazar.cloud.sdu.dk
1. app-sao-calisto-i.cloud.sdu.dk
1. app-santa-teresa-de-jesus.cloud.sdu.dk
1. app-santa-edwiges.cloud.sdu.dk
1. app-santo-inacio-de-antioquia.cloud.sdu.dk
1. app-sao-lucas.cloud.sdu.dk
1. app-joao-de-brebeuf-e-isaac-jogues.cloud.sdu.dk
1. app-sao-pedro-de-alcantara.cloud.sdu.dk
1. app-santa-ursula-e-santa-celina.cloud.sdu.dk
1. app-sao-joao-paulo-ii.cloud.sdu.dk
1. app-joao-de-capistrano.cloud.sdu.dk
1. app-santo-antonio-maria-claret.cloud.sdu.dk
1. app-santo-antonio-de-sant-ana-galvao.cloud.sdu.dk
1. app-santo-evaristo.cloud.sdu.dk
1. app-sao-goncalo-de-lagos.cloud.sdu.dk
1. app-sao-simao-e-sao-judas-tadeu.cloud.sdu.dk
1. app-sao-narciso-e-beata-chiara-luce-badano.cloud.sdu.dk
1. app-beata-maria-restituta-kafka.cloud.sdu.dk
1. app-santa-lucila-e-santo-afonso-rodrigues.cloud.sdu.dk
1. app-todos-os-santos.cloud.sdu.dk
1. app-todos-os-fieis-defuntos.cloud.sdu.dk
1. app-sao-martinho-de-porres.cloud.sdu.dk
1. app-carlos-borromeu.cloud.sdu.dk
1. app-sao-zacarias-e-santa-isabel.cloud.sdu.dk
1. app-sao-leonardo-de-noblac-e-sao-nuno-de-santa-maria-alvares-pereira.cloud.sdu.dk
1. app-sao-vilibrordo.cloud.sdu.dk
1. app-sao-orestes-e-dedicacao-da-basilica-de-sao-joao-de-latrao.cloud.sdu.dk
1. app-sao-leao-magno.cloud.sdu.dk
1. app-sao-martinho.cloud.sdu.dk
1. app-sao-josafa.cloud.sdu.dk
1. app-santo-estanislau-kostka.cloud.sdu.dk
1. app-sao-serapiao.cloud.sdu.dk
1. app-santo-alberto-magno.cloud.sdu.dk
1. app-margarida-da-escocia.cloud.sdu.dk
1. app-santa-isabel-da-hungria.cloud.sdu.dk
1. app-dedicacao-das-basilicas-de-sao-pedro-e-sao-paulo.cloud.sdu.dk
1. app-santos-roque-gonzalez.cloud.sdu.dk
1. app-sao-felix-de-valois.cloud.sdu.dk
1. app-apresentacao-de-nossa-senhora.cloud.sdu.dk
1. app-santa-cecilia.cloud.sdu.dk
1. app-sao-clemente-i.cloud.sdu.dk
1. app-santo-andre-dung.cloud.sdu.dk
1. app-santa-catarina-de-alexandria.cloud.sdu.dk
1. app-sao-leonardo-de-porto-mauricio.cloud.sdu.dk
1. app-nossa-senhora-das-gracas-e-medalha-milagrosa.cloud.sdu.dk
1. app-santa-catarina-laboure.cloud.sdu.dk
1. app-sao-saturnino-de-toulouse.cloud.sdu.dk
1. app-santo-andre.cloud.sdu.dk
1. app-santo-eligio.cloud.sdu.dk
1. app-sao-silverio.cloud.sdu.dk
1. app-sao-francisco-xavier.cloud.sdu.dk
1. app-joao-damasceno.cloud.sdu.dk
1. app-sao-sabas.cloud.sdu.dk
1. app-sao-nicolau-de-mira.cloud.sdu.dk
1. app-santo-ambrosio-de-milao.cloud.sdu.dk
1. app-imaculada-conceicao-da-virgem-maria.cloud.sdu.dk
1. app-sao-juan-diego.cloud.sdu.dk
1. app-sao-joao-roberts.cloud.sdu.dk
1. app-sao-damaso-i.cloud.sdu.dk
1. app-nossa-senhora-de-guadalupe.cloud.sdu.dk
1. app-santa-luzia.cloud.sdu.dk
1. app-sao-joao-da-cruz.cloud.sdu.dk
1. app-santa-cristiana.cloud.sdu.dk
1. app-santa-adelaide.cloud.sdu.dk
1. app-sao-lazaro.cloud.sdu.dk
1. app-sao-graciano.cloud.sdu.dk
1. app-papa-urbano-v.cloud.sdu.dk
1. app-sao-domingos-de-silos.cloud.sdu.dk
1. app-pedro-canisio.cloud.sdu.dk
1. app-francisca-xavier-cabrini.cloud.sdu.dk
1. app-sao-joao-cancio.cloud.sdu.dk
1. app-sao-charbel.cloud.sdu.dk
1. app-natal-do-senhor-jesus-cristo.cloud.sdu.dk
1. app-santo-estevao.cloud.sdu.dk
1. app-sao-joao.cloud.sdu.dk
1. app-santos-inocentes.cloud.sdu.dk
1. app-tomas-becket.cloud.sdu.dk
1. app-sao-rugero.cloud.sdu.dk
1. app-silvestre-i.cloud.sdu.dk
